pub enum SubYear {
NormalSubYear(NormalSubYear),
YearDay,
LeapDay,
}Expand description
The day and month of an ArvelieDate.
Variants
NormalSubYear(NormalSubYear)
A normal day/month pair.
YearDay
Year day. The last day of a normal year.
LeapDay
Leap day. The last day of a leap year.
Implementations
Sourceimpl SubYear
impl SubYear
Sourcepub fn format_month(&self) -> String
pub fn format_month(&self) -> String
Returns the month as a letter of the alphabet.
Sourcepub fn format_day(&self) -> String
pub fn format_day(&self) -> String
Returns the day of the month, formatted as a string.